OH_NativeBuffer_MetadataKey

Struct OH_NativeBuffer_MetadataKey 

#[repr(transparent)]
pub struct OH_NativeBuffer_MetadataKey(pub u32);
Available on crate features native_buffer and api-12 only.
Indicates the descriptive information of a native buffer, such as HDR metadata, ROI metadata, etc.

Required System Capabilities: SystemCapability.Graphic.Graphic2D.NativeBuffer

Available since API-level: 12

Version: 1.0

Tuple Fields

0: u32

Implementations

Source

impl OH_NativeBuffer_MetadataKey

pub const OH_HDR_METADATA_TYPE: OH_NativeBuffer_MetadataKey

value: OH_NativeBuffer_MetadataType

pub const OH_HDR_STATIC_METADATA: OH_NativeBuffer_MetadataKey

value: OH_NativeBuffer_StaticMetadata

pub const OH_HDR_DYNAMIC_METADATA: OH_NativeBuffer_MetadataKey

byte stream of SEI in video stream

pub const OH_REGION_OF_INTEREST_METADATA: OH_NativeBuffer_MetadataKey

Available on crate feature api-22 only.

Region of interest(ROI) metadata is used to conifgure ROI feature in video encoding. Value type is string in the format “Top1,Left1-Bottom1,Right1=QpOffset1;Top2,Left2-Bottom2,Right2=QpOffset2;”. Each “Top,Left-Bottom,Right=QpOffset” represents the coordinate information and quantization parameter offset of one ROI. Each “=QpOffset” in the string can be omitted, like “Top1,Left1-Bottom1,Right1;Top2,Left2-Bottom2,Right2=QpOffset2;”, the encoder will use the default quantization parameter offset to perform the ROI encoding on the first ROI and use QpOffset2 on the second ROI. Note that the number of ROIs that can be applied simultaneously does not exceed six, and the total area must not exceed one-fifth of the total image area.

Available since API-level: 22