OH_NativeImage_ReleaseTextImage

Function OH_NativeImage_ReleaseTextImage 

pub unsafe extern "C" fn OH_NativeImage_ReleaseTextImage(
    image: *mut OH_NativeImage,
) -> i32
Available on crate features native_image and api-22 only.
Release the OH_NativeImage in single buffer mode.

This interface suggest be called after the producer flushes the buffer to let the buffer queue rotate,

in the single buffer mode. This interface is a non-thread-safe type interface.

Required System Capabilities: SystemCapability.Graphic.Graphic2D.NativeImage

Arguments

  • image - Indicates the pointer to a OH_NativeImage instance.

Returns

  • [NATIVE_ERROR_OK] 0 - Success. [NATIVE_ERROR_INVALID_ARGUMENTS] 40001000 - image is NULL.

Available since API-level: 22

Version: 1.0